Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/org.eclipse.etrice.core.common/src-gen/org/eclipse/etrice/core/common/AbstractBaseRuntimeModule.java')
-rw-r--r--plugins/org.eclipse.etrice.core.common/src-gen/org/eclipse/etrice/core/common/AbstractBaseRuntimeModule.java11
1 files changed, 8 insertions, 3 deletions
diff --git a/plugins/org.eclipse.etrice.core.common/src-gen/org/eclipse/etrice/core/common/AbstractBaseRuntimeModule.java b/plugins/org.eclipse.etrice.core.common/src-gen/org/eclipse/etrice/core/common/AbstractBaseRuntimeModule.java
index fad15a03d..01fcc042a 100644
--- a/plugins/org.eclipse.etrice.core.common/src-gen/org/eclipse/etrice/core/common/AbstractBaseRuntimeModule.java
+++ b/plugins/org.eclipse.etrice.core.common/src-gen/org/eclipse/etrice/core/common/AbstractBaseRuntimeModule.java
@@ -148,9 +148,14 @@ public abstract class AbstractBaseRuntimeModule extends org.eclipse.xtext.servic
return org.eclipse.etrice.core.common.generator.BaseGenerator.class;
}
- // contributed by org.eclipse.xtext.generator.formatting.FormatterFragment
- public Class<? extends org.eclipse.xtext.formatting.IFormatter> bindIFormatter() {
- return org.eclipse.etrice.core.common.formatting.BaseFormatter.class;
+ // contributed by org.eclipse.xtext.generator.formatting2.Formatter2Fragment
+ public Class<? extends org.eclipse.xtext.formatting2.IFormatter2> bindIFormatter2() {
+ return org.eclipse.etrice.core.common.formatting2.BaseFormatter.class;
+ }
+
+ // contributed by org.eclipse.xtext.generator.formatting2.Formatter2Fragment
+ public void configureFormatterPreferences(com.google.inject.Binder binder) {
+ binder.bind(org.eclipse.xtext.preferences.IPreferenceValuesProvider.class).annotatedWith(org.eclipse.xtext.formatting2.FormatterPreferences.class).to(org.eclipse.xtext.formatting2.FormatterPreferenceValuesProvider.class);
}
}

Back to the top